// Copyright 2009-present MongoDB, Inc.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

#pragma once

#include <mongocxx/exception/logic_error-fwd.hpp>

#include <mongocxx/exception/exception.hpp>

#include <mongocxx/config/prelude.hpp>

namespace mongocxx {
namespace v_noabi {

///
/// An exception thrown due to incorrect use of mongocxx interfaces.
///
/// @see
/// - @ref mongocxx::v_noabi::exception
///
class logic_error : public exception {
   public:
    ~logic_error() override;

    logic_error(logic_error&&) = default;
    logic_error& operator=(logic_error&&) = default;
    logic_error(logic_error const&) = default;
    logic_error& operator=(logic_error const&) = default;

    using exception::exception;
};

} // namespace v_noabi
} // namespace mongocxx

#include <mongocxx/config/postlude.hpp>

///
/// @file
/// Provides @ref mongocxx::v_noabi::logic_error.
///
